# toopy
Python utilities and helper functions that have proven helpful

functionality includes:

+ publication plot helpers
+ pandas Dataframe helpers
+ A Parameter class based on pythons native float and integer types, which can store additional information
+ analysis tool for Casy Cell counting devices
+ prepending zeros to a filename that begins with an integer
+ text to speech programmable communication device
